package at.ac.uibk.gitsearch.service;

import java.util.Timer;
import java.util.TimerTask;

import javax.annotation.PostConstruct;
import javax.ws.rs.client.Client;
import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.MediaType;

import org.glassfish.jersey.client.ClientConfig;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.fasterxml.jackson.jaxrs.json.JacksonJsonProvider;

import at.ac.uibk.gitsearch.config.ApplicationProperties;
import at.ac.uibk.gitsearch.service.dto.BroadCastMessageDTO;

/**
 * this service provides messages. To make things simple, we use gitlab to
 * manage the (broadcast) messages.
 * 
 * @author Michael Breu
 *
 */
@Service
public class MessageService {

	private static final Logger log = LoggerFactory.getLogger(MessageService.class);


	@Autowired
	protected ApplicationProperties applicationProperties;

	BroadCastMessageDTO[] messages = null;

	public BroadCastMessageDTO[] getMessages() {
		return messages;
	}

	private static final long PLUGIN_RECHECK_TIMEOUT = 10 * 60 * 1000L; // every 10 Minutes

	@PostConstruct
	public void startReloadTimer() {
		Timer check = new Timer("MessageReloadTimer");
		check.schedule(new MessageLoaderTask(), 0, PLUGIN_RECHECK_TIMEOUT);
	}

	public class MessageLoaderTask extends TimerTask {
		public void run() {
			
			// Unfortunatelly the gitlab API does not yet support fetching of broadcast messages :-(
			ClientConfig restClientConfig = new ClientConfig();
			restClientConfig.register(JacksonJsonProvider.class);
			Client client = ClientBuilder.newClient(restClientConfig);

			WebTarget target = client.target(applicationProperties.getGitLab().getUrl() + "/api/v4/broadcast_messages");
			try {
				messages = target.request().accept(MediaType.APPLICATION_JSON).get(BroadCastMessageDTO[].class);
			} catch (Exception e) {
				log.warn("Cannot load broadcast messages from {}", e.getMessage());
			}
		}
	}
	
	/**
	 * this is for testing mainly.
	 */
	public void triggerReload() {
		new MessageLoaderTask().run();
	}

}
