package at.ac.uibk.gitsearch.service.dto;

import java.io.Serializable;
import java.util.Objects;

import at.ac.uibk.gitsearch.domain.enumeration.CheckFrequency;
import io.github.jhipster.service.Criteria;
import io.github.jhipster.service.filter.Filter;
import io.github.jhipster.service.filter.LongFilter;
import io.github.jhipster.service.filter.StringFilter;

/**
 * Criteria class for the {@link at.ac.uibk.gitsearch.domain.UserWatchList} entity. This class is used
 * in {@link at.ac.uibk.gitsearch.web.rest.UserWatchListResource} to receive all the possible filtering options from
 * the Http GET request parameters.
 * For example the following could be a valid request:
 * {@code /user-watch-lists?id.greaterThan=5&attr1.contains=something&attr2.specified=false}
 * As Spring is unable to properly convert the types, unless specific {@link Filter} class are used, we need to use
 * fix type specific filters.
 */
public class UserWatchListCriteria implements Serializable, Criteria {
    /**
     * Class for filtering CheckFrequency
     */
    public static class CheckFrequencyFilter extends Filter<CheckFrequency> implements Serializable {

        /**
		 * 
		 */
		private static final long serialVersionUID = 1L;

		public CheckFrequencyFilter() {
        }

        public CheckFrequencyFilter(CheckFrequencyFilter filter) {
            super(filter);
        }

        @Override
        public CheckFrequencyFilter copy() {
            return new CheckFrequencyFilter(this);
        }

    }

    private static final long serialVersionUID = 1L;

    private LongFilter id;

    private StringFilter name;

    private CheckFrequencyFilter checkFrequency;

    private LongFilter userId;

    public UserWatchListCriteria() {
    }

    public UserWatchListCriteria(UserWatchListCriteria other) {
        this.id = other.id == null ? null : other.id.copy();
        this.name = other.name == null ? null : other.name.copy();
        this.checkFrequency = other.checkFrequency == null ? null : other.checkFrequency.copy();
        this.userId = other.userId == null ? null : other.userId.copy();
    }

    @Override
    public UserWatchListCriteria copy() {
        return new UserWatchListCriteria(this);
    }

    public LongFilter getId() {
        return id;
    }

    public void setId(LongFilter id) {
        this.id = id;
    }

    public StringFilter getName() {
        return name;
    }

    public void setName(StringFilter name) {
        this.name = name;
    }

    public CheckFrequencyFilter getCheckFrequency() {
        return checkFrequency;
    }

    public void setCheckFrequency(CheckFrequencyFilter checkFrequency) {
        this.checkFrequency = checkFrequency;
    }

    public LongFilter getUserId() {
        return userId;
    }

    public void setUserId(LongFilter userId) {
        this.userId = userId;
    }


    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        final UserWatchListCriteria that = (UserWatchListCriteria) o;
        return
            Objects.equals(id, that.id) &&
            Objects.equals(name, that.name) &&
            Objects.equals(checkFrequency, that.checkFrequency) &&
            Objects.equals(userId, that.userId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(
        id,
        name,
        checkFrequency,
        userId
        );
    }

    // prettier-ignore
    @Override
    public String toString() {
        return "UserWatchListCriteria{" +
                (id != null ? "id=" + id + ", " : "") +
                (name != null ? "name=" + name + ", " : "") +
                (checkFrequency != null ? "checkFrequency=" + checkFrequency + ", " : "") +
                (userId != null ? "userId=" + userId + ", " : "") +
            "}";
    }

}
