import { Component, OnInit, OnDestroy } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { ActivatedRoute } from '@angular/router';
import { Subscription } from 'rxjs';
import { JhiEventManager } from 'ng-jhipster';
import { NgbModal } from '@ng-bootstrap/ng-bootstrap';

import { ILikes } from 'app/shared/model/likes.model';
import { LikesService } from './likes.service';
import { LikesDeleteDialogComponent } from './likes-delete-dialog.component';

@Component({
  selector: 'jhi-likes',
  templateUrl: './likes.component.html',
})
export class LikesComponent implements OnInit, OnDestroy {
  likes?: ILikes[];
  eventSubscriber?: Subscription;
  currentSearch: string;

  constructor(
    protected likesService: LikesService,
    protected eventManager: JhiEventManager,
    protected modalService: NgbModal,
    protected activatedRoute: ActivatedRoute
  ) {
    this.currentSearch =
      this.activatedRoute.snapshot && this.activatedRoute.snapshot.queryParams['search']
        ? this.activatedRoute.snapshot.queryParams['search']
        : '';
  }

  loadAll(): void {
    if (this.currentSearch) {
      this.likesService
        .search({
          query: this.currentSearch,
        })
        .subscribe((res: HttpResponse<ILikes[]>) => (this.likes = res.body || []));
      return;
    }

    this.likesService.query().subscribe((res: HttpResponse<ILikes[]>) => (this.likes = res.body || []));
  }

  search(query: string): void {
    this.currentSearch = query;
    this.loadAll();
  }

  ngOnInit(): void {
    this.loadAll();
    this.registerChangeInLikes();
  }

  ngOnDestroy(): void {
    if (this.eventSubscriber) {
      this.eventManager.destroy(this.eventSubscriber);
    }
  }

  trackId(index: number, item: ILikes): number {
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion
    return item.id!;
  }

  registerChangeInLikes(): void {
    this.eventSubscriber = this.eventManager.subscribe('likesListModification', () => this.loadAll());
  }

  delete(likes: ILikes): void {
    const modalRef = this.modalService.open(LikesDeleteDialogComponent, { size: 'lg', backdrop: 'static' });
    modalRef.componentInstance.likes = likes;
  }
}
